.. _recipe_asr.structureinfo:

asr.structureinfo
=================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.structureinfo`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.structureinfo.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.structureinfo

or as a python module

.. code-block:: console

   $ python -m asr.structureinfo

Detailed description
--------------------
Structural information.

Steps
-----


asr.structureinfo
^^^^^^^^^^^^^^^^^
.. autofunction:: asr.structureinfo.main
   